@@ -10,9 +10,6 @@ test_that("read_single_roi fails when expected", {
 
   # z does not exist in data
   expect_error(scopr:::read_single_roi(test_file,region_id = 1, columns=c("x", "z")), "Some of the requested columns are NOT available")
-
-  a <- scopr:::read_single_roi(test_file,region_id = 1)
-  a
 })
 
 
@@ -21,7 +18,7 @@ test_that("loading data works", {
   test_file <- paste(dir, "ethoscope_results/029/E_029/2016-01-25_21-14-55/2016-01-25_21-14-55_029.db",sep="/")
   #test_file  <- "/data/ethoscope_results/053c6ba04e534be486069c3db7b10827/ETHOSCOPE_053/2017-05-08_15-41-30/2017-05-08_15-41-30_053c6ba04e534be486069c3db7b10827.db"
   a <- scopr:::read_single_roi(test_file,region_id = 1)
-  # a
+  expect_s3_class(a, "data.table")
 })
 
 
